- Input
dataframe containing - at the minimum - Latitudes and Longitudes to be assigned to polygons.
If NamesIn is not provided, the columns in the Input must be in the following order:
Latitude, Longitude, Variable 1, Variable 2, ... Variable x..
- Polys
character vector of polygon names (e.g., Polys=c('ASDs','RBs')).
Must be matching the names of the pre-loaded spatial objects (loaded via e.g., ASDs=load_ASDs()).
- AreaNameFormat
dependent on the polygons loaded. For the Secretariat's spatial objects loaded via 'load_' functions,
we have the following:
'GAR_Name' e.g., 'Subarea 88.2'
'GAR_Short_Label' e.g., '882'
'GAR_Long_Label' (default) e.g., '88.2'
Several values may be entered if several Polys are used, e.g.:
c('GAR_Short_Label','GAR_Name'), in which case AreaNameFormat must be given in the same order as Polys.
- Buffer
numeric, distance in nautical miles to be added around the Polys of interest.
Can be specified for each of the Polys (e.g., Buffer=c(2,5)). Useful to determine whether locations are within
Buffer nautical miles of a polygon.
- NamesIn
character vector of length 2 specifying the column names of Latitude and Longitude fields in
the Input. Latitudes name must be given first, e.g.:
NamesIn=c('MyLatitudes','MyLongitudes').
- NamesOut
character, names of the resulting column names in the output dataframe,
with order matching that of Polys (e.g., NamesOut=c('Recapture_ASD','Recapture_RB')).
If not provided will be set as equal to Polys.